@@ -379,8 +379,8 @@ gst_get_main_executable_path (void)
 
 /**
  * gst_init_check:
- * @argc: (inout) (allow-none): pointer to application's argc
- * @argv: (inout) (array length=argc) (allow-none): pointer to application's argv
+ * @argc: (inout) (optional): pointer to application's argc
+ * @argv: (inout) (array length=argc) (optional): pointer to application's argv
  * @error: pointer to a #GError to which a message will be posted on error
  *
  * Initializes the GStreamer library, setting up internal path lists,
@@ -430,8 +430,8 @@ gst_init_check (int *argc, char **argv[], GError ** error)
 
 /**
  * gst_init:
- * @argc: (inout) (allow-none): pointer to application's argc
- * @argv: (inout) (array length=argc) (allow-none): pointer to application's argv
+ * @argc: (inout) (optional): pointer to application's argc
+ * @argv: (inout) (array length=argc) (optional): pointer to application's argv
  *
  * Initializes the GStreamer library, setting up internal path lists,
  * registering built-in elements, and loading standard plugins.
@@ -815,6 +815,12 @@ init_post (GOptionContext * context, GOptionGroup * group, gpointer data,
 
 #ifndef GST_DISABLE_GST_TRACER_HOOKS
   _priv_gst_tracing_init ();
+  /* Allow the `dots` tracer to set the `GST_DEBUG_DUMP_DOT_DIR` variable if it
+   * was not set before */
+#ifndef GST_DISABLE_GST_DEBUG
+  if (!priv_gst_dump_dot_dir)
+    priv_gst_dump_dot_dir = g_getenv ("GST_DEBUG_DUMP_DOT_DIR");
+#endif
 #endif
 
   return TRUE;
