@@ -533,5 +533,8 @@ void priv_gst_clock_init (void);
 GstClockTime priv_gst_get_monotonic_time (void);
 GstClockTime priv_gst_get_real_time (void);
 
+/* Needed for hashing in gstvalue.c */
+G_GNUC_INTERNAL const GstStructure * _gst_tag_list_structure (const GstTagList * list);
+
 G_END_DECLS
 #endif /* __GST_PRIVATE_H__ */
