@@ -437,7 +437,7 @@ gboolean       gst_buffer_unset_flags      (GstBuffer * buffer, GstBufferFlags f
 static inline GstBuffer *
 gst_buffer_ref (GstBuffer * buf)
 {
-  return (GstBuffer *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (buf));
+  return GST_BUFFER_CAST (gst_mini_object_ref (GST_MINI_OBJECT_CAST (buf)));
 }
 
 static inline void
@@ -453,10 +453,10 @@ gst_clear_buffer (GstBuffer ** buf_ptr)
 }
 
 /* copy buffer */
-static inline GstBuffer *
+G_GNUC_WARN_UNUSED_RESULT static inline GstBuffer *
 gst_buffer_copy (const GstBuffer * buf)
 {
-  return GST_BUFFER (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (buf)));
+  return GST_BUFFER_CAST (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (buf)));
 }
 #else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 GST_API
@@ -469,11 +469,11 @@ GST_API
 void        gst_clear_buffer     (GstBuffer ** buf_ptr);
 
 GST_API
-GstBuffer * gst_buffer_copy      (const GstBuffer * buf);
+GstBuffer * gst_buffer_copy      (const GstBuffer * buf) G_GNUC_WARN_UNUSED_RESULT;
 #endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 
 GST_API
-GstBuffer * gst_buffer_copy_deep (const GstBuffer * buf);
+GstBuffer * gst_buffer_copy_deep (const GstBuffer * buf) G_GNUC_WARN_UNUSED_RESULT;
 
 /**
  * GstBufferCopyFlags:
@@ -535,53 +535,54 @@ gboolean        gst_buffer_copy_into            (GstBuffer *dest, GstBuffer *src
                                                  GstBufferCopyFlags flags,
                                                  gsize offset, gsize size);
 
-/**
- * gst_buffer_is_writable:
- * @buf: a #GstBuffer
- *
- * Tests if you can safely write to a buffer's metadata or its memory array.
- * It is only safe to change buffer metadata when the current reference is
- * writable, i.e. nobody can see the modifications you will make.
- */
-#define         gst_buffer_is_writable(buf)     gst_mini_object_is_writable (GST_MINI_OBJECT_CAST (buf))
-/**
- * gst_buffer_make_writable:
- * @buf: (transfer full): a #GstBuffer
- *
- * Returns a writable copy of @buf. If the source buffer is
- * already writable, this will simply return the same buffer.
- *
- * Use this function to ensure that a buffer can be safely modified before
- * making changes to it, including changing the metadata such as PTS/DTS.
- *
- * If the reference count of the source buffer @buf is exactly one, the caller
- * is the sole owner and this function will return the buffer object unchanged.
- *
- * If there is more than one reference on the object, a copy will be made using
- * gst_buffer_copy(). The passed-in @buf will be unreffed in that case, and the
- * caller will now own a reference to the new returned buffer object. Note
- * that this just copies the buffer structure itself, the underlying memory is
- * not copied if it can be shared amongst multiple buffers.
- *
- * In short, this function unrefs the buf in the argument and refs the buffer
- * that it returns. Don't access the argument after calling this function unless
- * you have an additional reference to it.
- *
- * Returns: (transfer full) (nullable): a writable buffer (which may or may not be the
- *     same as @buf) or %NULL if copying is required but not possible.
- */
-#define         gst_buffer_make_writable(buf)   GST_BUFFER_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (buf)))
-
 #ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
+G_GNUC_WARN_UNUSED_RESULT static inline GstBuffer *
+gst_buffer_make_writable (GstBuffer * buf)
+{
+  return GST_BUFFER_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (buf)));
+}
+
+static inline gboolean
+gst_buffer_is_writable (const GstBuffer * buf)
+{
+  return gst_mini_object_is_writable (GST_MINI_OBJECT_CONST_CAST (buf));
+}
+
 static inline gboolean
 gst_buffer_replace (GstBuffer **obuf, GstBuffer *nbuf)
 {
   return gst_mini_object_replace ((GstMiniObject **) obuf, (GstMiniObject *) nbuf);
 }
+
+static inline GstBuffer *
+gst_buffer_steal(GstBuffer **old_buffer)
+{
+  return GST_BUFFER_CAST(gst_mini_object_steal((GstMiniObject **)old_buffer));
+}
+
+static inline gboolean
+gst_buffer_take(GstBuffer **old_buffer, GstBuffer *new_buffer)
+{
+  return gst_mini_object_take((GstMiniObject **)old_buffer, (GstMiniObject *)new_buffer);
+}
 #else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 GST_API
 gboolean        gst_buffer_replace              (GstBuffer ** obuf,
                                                  GstBuffer * nbuf);
+
+GST_API
+GstBuffer *gst_buffer_steal (GstBuffer **old_buffer);
+
+GST_API
+gboolean gst_buffer_take (GstBuffer ** old_buffer,
+                          GstBuffer *new_buffer);
+
+GST_API
+GstBuffer * gst_buffer_make_writable            (GstBuffer * buf) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
+gboolean gst_buffer_is_writable                 (const GstBuffer * buf);
+
 #endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 
 /* creating a region */
