@@ -24,6 +24,8 @@
 #ifndef __GST_CONTEXT_H__
 #define __GST_CONTEXT_H__
 
+#include <glib.h>
+
 G_BEGIN_DECLS
 
 typedef struct _GstContext GstContext;
@@ -31,7 +33,7 @@ typedef struct _GstContext GstContext;
 #include <gst/gstminiobject.h>
 #include <gst/gststructure.h>
 
-GST_EXPORT GType _gst_context_type;
+GST_API GType _gst_context_type;
 
 #define GST_TYPE_CONTEXT                         (_gst_context_type)
 #define GST_IS_CONTEXT(obj)                      (GST_IS_MINI_OBJECT_TYPE (obj, GST_TYPE_CONTEXT))
@@ -40,122 +42,96 @@ GST_EXPORT GType _gst_context_type;
 
 
 
+GST_API
 GType           gst_context_get_type            (void);
 
-
+#ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 /* refcounting */
-/**
- * gst_context_ref:
- * @context: the context to ref
- *
- * Convenience macro to increase the reference count of the context.
- *
- * Returns: @context (for convenience when doing assignments)
- */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstContext * gst_context_ref (GstContext * context);
-#endif
-
 static inline GstContext *
 gst_context_ref (GstContext * context)
 {
   return (GstContext *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (context));
 }
 
-/**
- * gst_context_unref:
- * @context: the context to unref
- *
- * Convenience macro to decrease the reference count of the context, possibly
- * freeing it.
- */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC void gst_context_unref (GstContext * context);
-#endif
-
 static inline void
 gst_context_unref (GstContext * context)
 {
   gst_mini_object_unref (GST_MINI_OBJECT_CAST (context));
 }
 
-/* copy context */
-/**
- * gst_context_copy:
- * @context: the context to copy
- *
- * Creates a copy of the context. Returns a copy of the context.
- *
- * Returns: (transfer full): a new copy of @context.
- *
- * MT safe
- */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstContext * gst_context_copy (const GstContext * context);
-#endif
+static inline void
+gst_clear_context (GstContext ** context_ptr)
+{
+  gst_clear_mini_object ((GstMiniObject **) context_ptr);
+}
 
-static inline GstContext *
+/* copy context */
+G_GNUC_WARN_UNUSED_RESULT static inline GstContext *
 gst_context_copy (const GstContext * context)
 {
   return GST_CONTEXT_CAST (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (context)));
 }
 
-/**
- * gst_context_is_writable:
- * @context: a #GstContext
- *
- * Tests if you can safely write into a context's structure or validly
- * modify the seqnum and timestamp fields.
- */
-#define         gst_context_is_writable(context)     gst_mini_object_is_writable (GST_MINI_OBJECT_CAST (context))
-/**
- * gst_context_make_writable:
- * @context: (transfer full): the context to make writable
- *
- * Checks if a context is writable. If not, a writable copy is made and
- * returned.
- *
- * Returns: (transfer full): a context (possibly a duplicate) that is writable.
- *
- * MT safe
- */
-#define         gst_context_make_writable(context)  GST_CONTEXT_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (context)))
-/**
- * gst_context_replace:
- * @old_context: (inout) (transfer full): pointer to a pointer to a #GstContext
- *     to be replaced.
- * @new_context: (allow-none) (transfer none): pointer to a #GstContext that will
- *     replace the context pointed to by @old_context.
- *
- * Modifies a pointer to a #GstContext to point to a different #GstContext. The
- * modification is done atomically (so this is useful for ensuring thread safety
- * in some cases), and the reference counts are updated appropriately (the old
- * context is unreffed, the new one is reffed).
- *
- * Either @new_context or the #GstContext pointed to by @old_context may be %NULL.
- *
- * Returns: %TRUE if @new_context was different from @old_context
- */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC gboolean gst_context_replace (GstContext **old_context, GstContext *new_context);
-#endif
+static inline gboolean
+gst_context_is_writable (const GstContext * context)
+{
+  return gst_mini_object_is_writable (GST_MINI_OBJECT_CONST_CAST (context));
+}
+
+G_GNUC_WARN_UNUSED_RESULT static inline GstContext *
+gst_context_make_writable (GstContext * context)
+{
+  return GST_CONTEXT_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (context)));
+}
 
 static inline gboolean
 gst_context_replace (GstContext **old_context, GstContext *new_context)
 {
   return gst_mini_object_replace ((GstMiniObject **) old_context, (GstMiniObject *) new_context);
 }
+#else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+GST_API
+GstContext * gst_context_ref    (GstContext * context);
 
+GST_API
+void         gst_context_unref  (GstContext * context);
+
+GST_API
+void         gst_clear_context  (GstContext ** context_ptr);
+
+GST_API
+GstContext * gst_context_copy   (const GstContext * context) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
+GstContext * gst_context_make_writable (GstContext * context) G_GNUC_WARN_UNUSED_RESULT;
+GST_API
+gboolean     gst_context_is_writable   (const GstContext * context);
+
+GST_API
+gboolean     gst_context_replace                  (GstContext ** old_context,
+                                                   GstContext * new_context);
+#endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+
+GST_API
 GstContext *          gst_context_new                      (const gchar * context_type,
                                                             gboolean persistent) G_GNUC_MALLOC;
-
+GST_API
 const gchar *         gst_context_get_context_type         (const GstContext * context);
+
+GST_API
 gboolean              gst_context_has_context_type         (const GstContext * context, const gchar * context_type);
+
+GST_API
 const GstStructure *  gst_context_get_structure            (const GstContext * context);
+
+GST_API
 GstStructure *        gst_context_writable_structure       (GstContext * context);
 
+GST_API
 gboolean              gst_context_is_persistent            (const GstContext * context);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstContext, gst_context_unref)
+
 G_END_DECLS
 
 #endif /* __GST_CONTEXT_H__ */
