@@ -67,6 +67,7 @@
 #include "config.h"
 #endif
 
+#define GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 #include "gst_private.h"
 #include "gstmemory.h"
 
@@ -94,7 +95,9 @@ _gst_memory_free (GstMemory * mem)
 
   allocator = mem->allocator;
 
+  GST_TRACER_MEMORY_FREE_PRE (mem);
   gst_allocator_free (allocator, mem);
+  GST_TRACER_MEMORY_FREE_POST (mem);
 
   gst_object_unref (allocator);
 }
@@ -138,6 +141,7 @@ gst_memory_init (GstMemory * mem, GstMemoryFlags flags,
   GST_CAT_DEBUG (GST_CAT_MEMORY, "new memory %p, maxsize:%" G_GSIZE_FORMAT
       " offset:%" G_GSIZE_FORMAT " size:%" G_GSIZE_FORMAT, mem, maxsize,
       offset, size);
+  GST_TRACER_MEMORY_INIT (mem);
 }
 
 /**
@@ -169,7 +173,7 @@ gst_memory_is_type (GstMemory * mem, const gchar * mem_type)
  *
  * Get the current @size, @offset and @maxsize of @mem.
  *
- * Returns: the current sizes of @mem
+ * Returns: the current size of @mem
  */
 gsize
 gst_memory_get_sizes (GstMemory * mem, gsize * offset, gsize * maxsize)
@@ -219,7 +223,7 @@ gst_memory_resize (GstMemory * mem, gssize offset, gsize size)
 /**
  * gst_memory_make_mapped:
  * @mem: (transfer full): a #GstMemory
- * @info: (out): pointer for info
+ * @info: (out caller-allocates): pointer for info
  * @flags: mapping flags
  *
  * Create a #GstMemory object that is mapped with @flags. If @mem is mappable
@@ -269,7 +273,7 @@ cannot_map:
 /**
  * gst_memory_map:
  * @mem: a #GstMemory
- * @info: (out): pointer for info
+ * @info: (out caller-allocates): pointer for info
  * @flags: mapping flags
  *
  * Fill @info with the pointer and sizes of the memory in @mem that can be
@@ -362,7 +366,7 @@ gst_memory_unmap (GstMemory * mem, GstMapInfo * info)
  * guaranteed to be writable. @size can be set to -1 to return a copy
  * from @offset to the end of the memory region.
  *
- * Returns: a new #GstMemory.
+ * Returns: (transfer full) (nullable): a new copy of @mem if the copy succeeded, %NULL otherwise.
  */
 GstMemory *
 gst_memory_copy (GstMemory * mem, gssize offset, gssize size)
@@ -464,3 +468,133 @@ _priv_gst_memory_initialize (void)
 {
   _gst_memory_type = gst_memory_get_type ();
 }
+
+/**
+ * gst_memory_ref: (skip)
+ * @memory: The memory to refcount
+ *
+ * Increase the refcount of this memory.
+ *
+ * Returns: (transfer full): @memory (for convenience when doing assignments)
+ */
+GstMemory *
+gst_memory_ref (GstMemory * memory)
+{
+  return (GstMemory *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (memory));
+}
+
+/**
+ * gst_memory_unref: (skip)
+ * @memory: (transfer full): the memory to refcount
+ *
+ * Decrease the refcount of a memory, freeing it if the refcount reaches 0.
+ */
+void
+gst_memory_unref (GstMemory * memory)
+{
+  gst_mini_object_unref (GST_MINI_OBJECT_CAST (memory));
+}
+
+/**
+ * gst_memory_is_writable:
+ * @memory: a #GstMemory
+ *
+ * Tests if you can safely modify @memory. It is only safe to modify memory when
+ * there is only one owner of the memory - ie, the object is writable.
+ */
+gboolean
+gst_memory_is_writable (const GstMemory * memory)
+{
+  return gst_mini_object_is_writable (GST_MINI_OBJECT_CONST_CAST (memory));
+}
+
+/**
+ * gst_memory_make_writable:
+ * @memory: (transfer full): a #GstMemory
+ *
+ * Returns a writable copy of @memory.
+ *
+ * If there is only one reference count on @memory, the caller must be the owner,
+ * and so this function will return the memory object unchanged. If on the other
+ * hand there is more than one reference on the object, a new memory object will
+ * be returned. The caller's reference on @memory will be removed, and instead the
+ * caller will own a reference to the returned object.
+ *
+ * In short, this function unrefs the memory in the argument and refs the memory
+ * that it returns. Don't access the argument after calling this function. See
+ * also: gst_memory_ref().
+ *
+ * Returns: (transfer full): a writable memory which may or may not be the
+ *     same as @memory
+ */
+GstMemory *
+gst_memory_make_writable (GstMemory * memory)
+{
+  return
+      GST_MEMORY_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST
+          (memory)));
+}
+
+/**
+ * gst_memory_replace: (skip)
+ * @old_memory: (inout) (transfer full) (nullable): pointer to a pointer to
+ *     a #GstMemory to be replaced.
+ * @new_memory: (transfer none) (allow-none): pointer to a #GstMemory that will
+ *     replace the memory pointed to by @old_memory.
+ *
+ * Modifies a pointer to a #GstMemory to point to a different #GstMemory. The
+ * modification is done atomically (so this is useful for ensuring thread safety
+ * in some cases), and the reference counts are updated appropriately (the old
+ * memory is unreffed, the new is reffed).
+ *
+ * Either @new_memory or the #GstMemory pointed to by @old_memory may be %NULL.
+ *
+ * Returns: %TRUE when @old_memory was different from @new_memory.
+ *
+ * Since: 1.28
+ */
+gboolean
+gst_memory_replace (GstMemory ** old_memory, GstMemory * new_memory)
+{
+  return gst_mini_object_replace ((GstMiniObject **) old_memory,
+      (GstMiniObject *) new_memory);
+}
+
+/**
+ * gst_memory_steal: (skip)
+ * @old_memory: (inout) (transfer full) (nullable): pointer to a
+ *     pointer to a #GstMemory to be stolen.
+ *
+ * Atomically replace the #GstMemory pointed to by @old_memory with %NULL and
+ * return the original memory.
+ * Since: 1.28
+ */
+GstMemory *
+gst_memory_steal (GstMemory ** old_memory)
+{
+  return GST_MEMORY_CAST (gst_mini_object_steal ((GstMiniObject **)
+          old_memory));
+}
+
+/**
+ * gst_memory_take: (skip)
+ * @old_memory: (inout) (transfer full) (nullable): pointer to a
+ *     pointer to a #GstMemory to be stolen.
+ * @new_memory: (nullable) (transfer full): pointer to a #GstMemory that will
+ *     replace the memory pointed to by @old_memory.
+ *
+ * Modifies a pointer to a #GstMemory to point to a different #GstMemory. This
+ * function is similar to gst_memory_replace() except that it takes ownership of
+ * @new_memory.
+ *
+ * Either @new_memory or the #GstMemory pointed to by @old_memory may be %NULL.
+ *
+ * Returns: %TRUE if @new_memory was different from @old_memory
+ * Since: 1.28
+ */
+gboolean
+gst_memory_take (GstMemory ** old_memory, GstMemory * new_memory)
+{
+  return gst_mini_object_take ((GstMiniObject **) old_memory,
+      (GstMiniObject *) new_memory);
+}
