@@ -48,6 +48,7 @@
 
 #include "gstbuffer.h"
 #include "gstmeta.h"
+#include "gstmetafactory.h"
 #include "gstinfo.h"
 #include "gstutils.h"
 
@@ -412,6 +413,38 @@ gst_meta_api_type_get_tags (GType api)
   return (const gchar * const *) tags;
 }
 
+/**
+ * gst_meta_api_type_tags_contain_only:
+ * @api: an API
+ * @valid_tags: (array zero-terminated=1) (element-type utf8): a list of valid tags
+ *
+ * Returns: %TRUE if @api only contains tags from @valid_tags.
+ *
+ * Since: 1.28
+ */
+gboolean
+gst_meta_api_type_tags_contain_only (GType api, const gchar ** valid_tags)
+{
+  const gchar **tags, **curr;
+
+  g_return_val_if_fail (api != 0, FALSE);
+  g_return_val_if_fail (valid_tags != NULL, FALSE);
+
+  tags = g_type_get_qdata (api, _gst_meta_tags_quark);
+
+  if (!tags)
+    return TRUE;
+
+  for (curr = tags; *curr; ++curr) {
+
+    if (!g_strv_contains (valid_tags, *curr)) {
+      return FALSE;
+    }
+  }
+
+  return TRUE;
+}
+
 /**
  * gst_meta_api_type_aggregate_params:
  * @api: the GType of the API for which the parameters are being aggregated.
@@ -792,7 +825,7 @@ gst_meta_serialize_simple (const GstMeta * meta, GByteArray * data)
 /**
  * gst_meta_deserialize:
  * @buffer: a #GstBuffer
- * @data: serialization data obtained from gst_meta_serialize()
+ * @data: (array length=size): serialization data obtained from gst_meta_serialize()
  * @size: size of @data
  * @consumed: (out): total size used by this meta, could be less than @size
  *
@@ -839,9 +872,12 @@ gst_meta_deserialize (GstBuffer * buffer, const guint8 * data, gsize size,
 
   const GstMetaInfo *info = gst_meta_get_info (name);
   if (info == NULL) {
-    GST_CAT_WARNING (GST_CAT_META,
-        "%s does not correspond to a registered meta", name);
-    return NULL;
+    info = gst_meta_factory_load (name);
+    if (info == NULL) {
+      GST_CAT_WARNING (GST_CAT_META,
+          "%s does not correspond to a registered meta", name);
+      return NULL;
+    }
   }
 
   if (info->deserialize_func == NULL) {
