@@ -25,12 +25,41 @@
 #include <gst/gstclock.h>
 #include <gst/gstdatetime.h>
 #include <gst/glib-compat.h>
+#include <gst/gstidstr.h>
 
 G_BEGIN_DECLS
 
 GST_API GType _gst_structure_type;
 
 typedef struct _GstStructure GstStructure;
+typedef struct _GstCaps GstCaps;
+
+/**
+ * GST_SERIALIZE_FLAG_STRICT:
+ *
+ * Serialization fails if a value cannot be serialized instead of using
+ * placeholder "NULL" value (e.g. pointers, objects).
+ *
+ * Since: 1.24
+ */
+
+/**
+ * GstSerializeFlags:
+ * @GST_SERIALIZE_FLAG_NONE: No special flags specified.
+ * @GST_SERIALIZE_FLAG_BACKWARD_COMPAT: Serialize using the old format for
+ *                                      nested structures.
+ * @GST_SERIALIZE_FLAG_STRICT: Serialization fails if a value cannot be
+ *  serialized instead of using placeholder "NULL" value (e.g. pointers,
+ *  objects). (Since 1.24)
+ *
+ * Since: 1.20
+ */
+typedef enum
+{
+  GST_SERIALIZE_FLAG_NONE = 0,
+  GST_SERIALIZE_FLAG_BACKWARD_COMPAT = (1 << 0),
+  GST_SERIALIZE_FLAG_STRICT = (1 << 1),
+} GstSerializeFlags;
 
 #define GST_TYPE_STRUCTURE             (_gst_structure_type)
 #define GST_IS_STRUCTURE(object)       ((object) && (GST_STRUCTURE(object)->type == GST_TYPE_STRUCTURE))
@@ -87,6 +116,61 @@ typedef gboolean (*GstStructureFilterMapFunc) (GQuark   field_id,
                                                GValue * value,
                                                gpointer user_data);
 
+/**
+ * GstStructureForeachIdStrFunc:
+ * @fieldname: the #GstIdStr field name
+ * @value: the #GValue of the field
+ * @user_data: user data
+ *
+ * A function that will be called in gst_structure_foreach_id_str(). The
+ * function may not modify @value.
+ *
+ * Returns: %TRUE if the foreach operation should continue, %FALSE if
+ * the foreach operation should stop with %FALSE.
+ *
+ * Since: 1.26
+ */
+typedef gboolean (*GstStructureForeachIdStrFunc) (const GstIdStr * fieldname,
+                                                  const GValue   * value,
+                                                  gpointer         user_data);
+
+/**
+ * GstStructureMapIdStrFunc:
+ * @fieldname: the #GstIdStr field name
+ * @value: the #GValue of the field
+ * @user_data: user data
+ *
+ * A function that will be called in gst_structure_map_in_place_id_str(). The
+ * function may modify @value.
+ *
+ * Returns: %TRUE if the map operation should continue, %FALSE if
+ * the map operation should stop with %FALSE.
+ *
+ * Since: 1.26
+ */
+typedef gboolean (*GstStructureMapIdStrFunc)     (const GstIdStr * fieldname,
+                                                  GValue         * value,
+                                                  gpointer         user_data);
+
+/**
+ * GstStructureFilterMapIdStrFunc:
+ * @fieldname: the #GstIdStr field name
+ * @value: the #GValue of the field
+ * @user_data: user data
+ *
+ * A function that will be called in gst_structure_filter_and_map_in_place_id_str().
+ * The function may modify @value, and the value will be removed from the
+ * structure if %FALSE is returned.
+ *
+ * Returns: %TRUE if the field should be preserved, %FALSE if it
+ * should be removed.
+ *
+ * Since: 1.26
+ */
+typedef gboolean (*GstStructureFilterMapIdStrFunc) (const GstIdStr * fieldname,
+                                                   GValue          * value,
+                                                   gpointer          user_data);
+
 /**
  * GstStructure:
  * @type: the GType of a structure
@@ -107,20 +191,44 @@ GST_API
 GstStructure *        gst_structure_new_empty            (const gchar * name) G_GNUC_MALLOC;
 
 GST_API
+GstStructure *        gst_structure_new_static_str_empty (const gchar * name) G_GNUC_MALLOC;
+
+GST_DEPRECATED_FOR(gst_structure_new_id_str_empty)
 GstStructure *        gst_structure_new_id_empty         (GQuark quark) G_GNUC_MALLOC;
 
+GST_API
+GstStructure *        gst_structure_new_id_str_empty     (const GstIdStr *name) G_GNUC_MALLOC;
+
 GST_API
 GstStructure *        gst_structure_new                  (const gchar * name,
                                                           const gchar * firstfield,
                                                           ...) G_GNUC_NULL_TERMINATED  G_GNUC_MALLOC;
 GST_API
+GstStructure *        gst_structure_new_static_str       (const gchar * name,
+                                                          const gchar * firstfield,
+                                                          ...) G_GNUC_NULL_TERMINATED  G_GNUC_MALLOC;
+GST_API
+GstStructure *        gst_structure_new_id_str_valist    (const GstIdStr * name,
+                                                          const GstIdStr * firstfield,
+                                                          va_list       varargs) G_GNUC_MALLOC;
+GST_API
 GstStructure *        gst_structure_new_valist           (const gchar * name,
                                                           const gchar * firstfield,
                                                           va_list       varargs) G_GNUC_MALLOC;
 GST_API
+GstStructure *        gst_structure_new_static_str_valist(const gchar * name,
+                                                          const gchar * firstfield,
+                                                          va_list       varargs) G_GNUC_MALLOC;
+GST_DEPRECATED_FOR(gst_structure_new_id_str)
 GstStructure *        gst_structure_new_id               (GQuark name_quark,
                                                           GQuark field_quark,
                                                           ...) G_GNUC_MALLOC;
+
+GST_API
+GstStructure *        gst_structure_new_id_str           (const GstIdStr *name,
+                                                          const GstIdStr *fieldname,
+                                                          ...) G_GNUC_NULL_TERMINATED G_GNUC_MALLOC;
+
 GST_API
 GstStructure *        gst_structure_new_from_string      (const gchar * string);
 
@@ -137,27 +245,47 @@ GST_API
 void                  gst_clear_structure                (GstStructure **structure_ptr);
 #define               gst_clear_structure(structure_ptr) g_clear_pointer ((structure_ptr), gst_structure_free)
 
+GST_API
+gboolean              gst_structure_take                 (GstStructure ** oldstr_ptr,
+                                                          GstStructure * newstr);
 GST_API
 const gchar *         gst_structure_get_name             (const GstStructure  * structure);
 
-GST_API
+GST_DEPRECATED_FOR(gst_structure_get_name_id_str)
 GQuark                gst_structure_get_name_id          (const GstStructure  * structure);
 
+GST_API
+const GstIdStr *      gst_structure_get_name_id_str      (const GstStructure  * structure);
+
 GST_API
 gboolean              gst_structure_has_name             (const GstStructure  * structure,
                                                           const gchar         * name);
 GST_API
+void                  gst_structure_set_name_id_str      (GstStructure        * structure,
+                                                          const GstIdStr      * name);
+GST_API
 void                  gst_structure_set_name             (GstStructure        * structure,
                                                           const gchar         * name);
 GST_API
+void                  gst_structure_set_name_static_str  (GstStructure        * structure,
+                                                          const gchar         * name);
+GST_DEPRECATED_FOR(gst_structure_id_str_set_value)
 void                  gst_structure_id_set_value         (GstStructure        * structure,
                                                           GQuark                field,
                                                           const GValue        * value);
 GST_API
+void                  gst_structure_id_str_set_value     (GstStructure        * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          const GValue        * value);
+GST_API
 void                  gst_structure_set_value            (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           const GValue        * value);
 GST_API
+void                  gst_structure_set_value_static_str (GstStructure        * structure,
+                                                          const gchar         * fieldname,
+                                                          const GValue        * value);
+GST_API
 void                  gst_structure_set_array            (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           const GValueArray   * array);
@@ -165,31 +293,55 @@ GST_API
 void                  gst_structure_set_list             (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           const GValueArray   * array);
-GST_API
+GST_DEPRECATED_FOR(gst_structure_id_str_take_value)
 void                  gst_structure_id_take_value        (GstStructure        * structure,
                                                           GQuark                field,
                                                           GValue              * value);
 GST_API
+void                  gst_structure_id_str_take_value    (GstStructure        * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          GValue              * value);
+GST_API
 void                  gst_structure_take_value           (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           GValue              * value);
 GST_API
+void                  gst_structure_take_value_static_str(GstStructure        * structure,
+                                                          const gchar         * fieldname,
+                                                          GValue              * value);
+GST_API
 void                  gst_structure_set                  (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           ...) G_GNUC_NULL_TERMINATED;
 GST_API
+void                  gst_structure_set_static_str       (GstStructure        * structure,
+                                                          const gchar         * fieldname,
+                                                          ...) G_GNUC_NULL_TERMINATED;
+GST_API
 void                  gst_structure_set_valist           (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           va_list varargs);
 GST_API
+void                  gst_structure_set_static_str_valist(GstStructure        * structure,
+                                                          const gchar         * fieldname,
+                                                          va_list varargs);
+GST_DEPRECATED_FOR(gst_structure_id_str_set)
 void                  gst_structure_id_set               (GstStructure        * structure,
                                                           GQuark                fieldname,
                                                           ...) G_GNUC_NULL_TERMINATED;
 GST_API
+void                  gst_structure_id_str_set           (GstStructure        * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          ...) G_GNUC_NULL_TERMINATED;
+GST_DEPRECATED_FOR(gst_structure_id_str_set_valist)
 void                  gst_structure_id_set_valist        (GstStructure        * structure,
                                                           GQuark                fieldname,
                                                           va_list varargs);
 GST_API
+void                  gst_structure_id_str_set_valist    (GstStructure        * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          va_list varargs);
+GST_API
 gboolean              gst_structure_get_valist           (const GstStructure  * structure,
                                                           const char          * first_fieldname,
                                                           va_list              args);
@@ -198,17 +350,28 @@ gboolean              gst_structure_get                  (const GstStructure  *
                                                           const char          * first_fieldname,
                                                           ...) G_GNUC_NULL_TERMINATED;
 GST_API
+gboolean              gst_structure_id_str_get_valist    (const GstStructure  * structure,
+                                                          const GstIdStr      * first_fieldname,
+                                                          va_list              args);
+GST_API
+gboolean              gst_structure_id_str_get           (const GstStructure  * structure,
+                                                          const GstIdStr      * first_fieldname,
+                                                          ...) G_GNUC_NULL_TERMINATED;
+GST_DEPRECATED_FOR(gst_structure_id_str_get_valist)
 gboolean              gst_structure_id_get_valist        (const GstStructure  * structure,
                                                           GQuark                first_field_id,
                                                           va_list               args);
-GST_API
+GST_DEPRECATED_FOR(gst_structure_id_str_get)
 gboolean              gst_structure_id_get               (const GstStructure  * structure,
                                                           GQuark                first_field_id,
                                                           ...) G_GNUC_NULL_TERMINATED;
-GST_API
+GST_DEPRECATED_FOR(gst_structure_id_str_get_value)
 const GValue *        gst_structure_id_get_value         (const GstStructure  * structure,
                                                           GQuark                field);
 GST_API
+const GValue *        gst_structure_id_str_get_value     (const GstStructure  * structure,
+                                                          const GstIdStr      * fieldname);
+GST_API
 const GValue *        gst_structure_get_value            (const GstStructure  * structure,
                                                           const gchar         * fieldname);
 GST_API
@@ -223,23 +386,49 @@ void                  gst_structure_remove_fields_valist (GstStructure        *
                                                           const gchar         * fieldname,
                                                           va_list               varargs);
 GST_API
+void                  gst_structure_id_str_remove_field  (GstStructure        * structure,
+                                                          const GstIdStr      * fieldname);
+GST_API
+void                  gst_structure_id_str_remove_fields (GstStructure        * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          ...) G_GNUC_NULL_TERMINATED;
+GST_API
+void                  gst_structure_id_str_remove_fields_valist(GstStructure  * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          va_list               varargs);
+GST_API
 void                  gst_structure_remove_all_fields    (GstStructure        * structure);
 
 GST_API
 GType                 gst_structure_get_field_type       (const GstStructure  * structure,
                                                           const gchar         * fieldname);
 GST_API
+GType                 gst_structure_id_str_get_field_type(const GstStructure  * structure,
+                                                          const GstIdStr      * fieldname);
+GST_DEPRECATED_FOR(gst_structure_foreach_id_str)
 gboolean              gst_structure_foreach              (const GstStructure  * structure,
                                                           GstStructureForeachFunc   func,
                                                           gpointer              user_data);
-GST_API
+GST_DEPRECATED_FOR(gst_structure_map_in_place_id_str)
 gboolean              gst_structure_map_in_place         (GstStructure        * structure,
                                                           GstStructureMapFunc   func,
                                                           gpointer              user_data);
+GST_DEPRECATED_FOR(gst_structure_filter_and_map_in_place_id_str)
+void                  gst_structure_filter_and_map_in_place (GstStructure             * structure,
+                                                              GstStructureFilterMapFunc func,
+                                                              gpointer                  user_data);
 GST_API
-void                  gst_structure_filter_and_map_in_place (GstStructure        * structure,
-                                                          GstStructureFilterMapFunc   func,
-                                                          gpointer              user_data);
+gboolean              gst_structure_foreach_id_str       (const GstStructure         * structure,
+                                                          GstStructureForeachIdStrFunc func,
+                                                          gpointer                     user_data);
+GST_API
+gboolean              gst_structure_map_in_place_id_str  (GstStructure           * structure,
+                                                          GstStructureMapIdStrFunc func,
+                                                          gpointer                 user_data);
+GST_API
+void                  gst_structure_filter_and_map_in_place_id_str (GstStructure                 * structure,
+                                                                    GstStructureFilterMapIdStrFunc func,
+                                                                    gpointer                       user_data);
 GST_API
 gint                  gst_structure_n_fields             (const GstStructure  * structure);
 
@@ -247,9 +436,12 @@ GST_API
 const gchar *         gst_structure_nth_field_name       (const GstStructure  * structure,
                                                           guint                 index);
 GST_API
+const GstIdStr *      gst_structure_id_str_nth_field_name(const GstStructure  * structure,
+                                                          guint                 index);
+GST_DEPRECATED_FOR(gst_structure_id_str_has_field)
 gboolean              gst_structure_id_has_field         (const GstStructure  * structure,
                                                           GQuark                field);
-GST_API
+GST_DEPRECATED_FOR(gst_structure_id_str_has_field_typed)
 gboolean              gst_structure_id_has_field_typed   (const GstStructure  * structure,
                                                           GQuark                field,
                                                           GType                 type);
@@ -260,6 +452,13 @@ GST_API
 gboolean              gst_structure_has_field_typed      (const GstStructure  * structure,
                                                           const gchar         * fieldname,
                                                           GType                 type);
+GST_API
+gboolean              gst_structure_id_str_has_field     (const GstStructure  * structure,
+                                                          const GstIdStr      * fieldname);
+GST_API
+gboolean              gst_structure_id_str_has_field_typed(const GstStructure  * structure,
+                                                          const GstIdStr      * fieldname,
+                                                          GType                 type);
 
 /* utility functions */
 
@@ -325,8 +524,21 @@ GST_API
 gboolean              gst_structure_get_list             (GstStructure        * structure,
                                                           const gchar         * fieldname,
                                                           GValueArray        ** array);
+
 GST_API
-gchar *               gst_structure_to_string    (const GstStructure * structure) G_GNUC_MALLOC;
+gboolean              gst_structure_get_flags            (const GstStructure  * structure,
+                                                          const gchar         * fieldname,
+                                                          GType                 flags_type,
+                                                          guint               * value);
+
+GST_API
+gchar *               gst_structure_to_string            (const GstStructure * structure) G_GNUC_MALLOC;
+GST_DEPRECATED_FOR(gst_structure_serialize_full)
+gchar *               gst_structure_serialize            (const GstStructure * structure,
+                                                          GstSerializeFlags flags) G_GNUC_MALLOC;
+GST_API
+gchar *               gst_structure_serialize_full       (const GstStructure * structure,
+                                                          GstSerializeFlags flags) G_GNUC_MALLOC;
 
 GST_API
 GstStructure *        gst_structure_from_string  (const gchar * string,
@@ -370,10 +582,15 @@ gboolean              gst_structure_can_intersect (const GstStructure * struct1,
 GST_API
 GstStructure *        gst_structure_intersect     (const GstStructure * struct1,
                                                    const GstStructure * struct2) G_GNUC_MALLOC;
+GST_API
+gboolean              gst_structure_get_caps      (const GstStructure * structure,
+                                                   const gchar * fieldname,
+                                                   const GstCaps ** caps);
+
+GST_API
+gboolean              gst_structure_is_writable   (const GstStructure        * structure);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstStructure, gst_structure_free)
-#endif
 
 G_END_DECLS
 
