@@ -201,7 +201,7 @@ GST_API
 GstTagList * gst_tag_list_new_empty         (void) G_GNUC_MALLOC;
 
 GST_API
-GstTagList * gst_tag_list_new               (const gchar * tag, ...) G_GNUC_MALLOC;
+GstTagList * gst_tag_list_new               (const gchar * tag, ...) G_GNUC_NULL_TERMINATED G_GNUC_MALLOC;
 
 GST_API
 GstTagList * gst_tag_list_new_valist        (va_list var_args) G_GNUC_MALLOC;
@@ -399,84 +399,32 @@ gboolean     gst_tag_list_get_sample_index  (const GstTagList * list,
                                              guint              index,
                                              GstSample       ** sample);
 
+#ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 /* refcounting */
-/**
- * gst_tag_list_ref: (skip)
- * @taglist: the #GstTagList to reference
- *
- * Add a reference to a #GstTagList mini object.
- *
- * From this point on, until the caller calls gst_tag_list_unref() or
- * gst_tag_list_make_writable(), it is guaranteed that the taglist object will
- * not change. To use a #GstTagList object, you must always have a refcount on
- * it -- either the one made implicitly by e.g. gst_tag_list_new(), or via
- * taking one explicitly with this function.
- *
- * Returns: the same #GstTagList mini object.
- */
-static inline GstTagList* gst_tag_list_ref(GstTagList* taglist);
 static inline GstTagList *
 gst_tag_list_ref (GstTagList * taglist)
 {
   return (GstTagList *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (taglist));
 }
 
-/**
- * gst_tag_list_unref: (skip)
- * @taglist: a #GstTagList.
- *
- * Unref a #GstTagList, and and free all its memory when the refcount reaches 0.
- */
-static inline void gst_tag_list_unref(GstTagList* taglist);
 static inline void
 gst_tag_list_unref (GstTagList * taglist)
 {
   gst_mini_object_unref (GST_MINI_OBJECT_CAST (taglist));
 }
 
-/**
- * gst_clear_tag_list: (skip)
- * @taglist_ptr: a pointer to a #GstTagList reference
- *
- * Clears a reference to a #GstTagList.
- *
- * @taglist_ptr must not be %NULL.
- *
- * If the reference is %NULL then this function does nothing. Otherwise, the
- * reference count of the taglist is decreased and the pointer is set to %NULL.
- *
- * Since: 1.16
- */
 static inline void
 gst_clear_tag_list (GstTagList ** taglist_ptr)
 {
   gst_clear_mini_object ((GstMiniObject **) taglist_ptr);
 }
 
-GST_API
-GstTagList* gst_tag_list_copy(const GstTagList* taglist);
+G_GNUC_WARN_UNUSED_RESULT static inline GstTagList *
+gst_tag_list_copy (const GstTagList * taglist)
+{
+  return (GstTagList *) (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (taglist)));
+}
 
-#define gst_tag_list_copy(taglist) GST_TAG_LIST (gst_mini_object_copy (GST_MINI_OBJECT_CAST (taglist)))
-
-/**
- * gst_tag_list_replace:
- * @old_taglist: (inout) (transfer full) (nullable): pointer to a pointer to a
- *     #GstTagList to be replaced.
- * @new_taglist: (transfer none) (allow-none): pointer to a #GstTagList that
- *     will replace the tag list pointed to by @old_taglist.
- *
- * Modifies a pointer to a #GstTagList to point to a different #GstTagList. The
- * modification is done atomically (so this is useful for ensuring thread
- * safety in some cases), and the reference counts are updated appropriately
- * (the old tag list is unreffed, the new is reffed).
- *
- * Either @new_taglist or the #GstTagList pointed to by @old_taglist may be
- * %NULL.
- *
- * Returns: %TRUE if @new_taglist was different from @old_taglist
- *
- * Since: 1.16
- */
 static inline gboolean
 gst_tag_list_replace (GstTagList **old_taglist, GstTagList *new_taglist)
 {
@@ -484,21 +432,6 @@ gst_tag_list_replace (GstTagList **old_taglist, GstTagList *new_taglist)
         (GstMiniObject *) new_taglist);
 }
 
-/**
- * gst_tag_list_take:
- * @old_taglist: (inout) (transfer full): pointer to a pointer to a #GstTagList
- *     to be replaced.
- * @new_taglist: (transfer full) (allow-none): pointer to a #GstTagList that
- *     will replace the taglist pointed to by @old_taglist.
- *
- * Modifies a pointer to a #GstTagList to point to a different #GstTagList.
- * This function is similar to gst_tag_list_replace() except that it takes
- * ownership of @new_taglist.
- *
- * Returns: %TRUE if @new_taglist was different from @old_taglist
- *
- * Since: 1.16
- */
 static inline gboolean
 gst_tag_list_take (GstTagList **old_taglist, GstTagList *new_taglist)
 {
@@ -506,36 +439,43 @@ gst_tag_list_take (GstTagList **old_taglist, GstTagList *new_taglist)
       (GstMiniObject *) new_taglist);
 }
 
-/**
- * gst_tag_list_is_writable:
- * @taglist: a #GstTagList
- *
- * Tests if you can safely modify @taglist. It is only safe to modify taglist
- * when there is only one owner of the taglist - ie, the refcount is 1.
- */
-#define gst_tag_list_is_writable(taglist)    gst_mini_object_is_writable (GST_MINI_OBJECT_CAST (taglist))
+static inline gboolean
+gst_tag_list_is_writable (const GstTagList * taglist)
+{
+  return gst_mini_object_is_writable (GST_MINI_OBJECT_CONST_CAST (taglist));
+}
 
-/**
- * gst_tag_list_make_writable:
- * @taglist: (transfer full): a #GstTagList
- *
- * Returns a writable copy of @taglist.
- *
- * If there is only one reference count on @taglist, the caller must be the
- * owner, and so this function will return the taglist object unchanged. If on
- * the other hand there is more than one reference on the object, a new taglist
- * object will be returned (which will be a copy of @taglist). The caller's
- * reference on @taglist will be removed, and instead the caller will own a
- * reference to the returned object.
- *
- * In short, this function unrefs the taglist in the argument and refs the
- * taglist that it returns. Don't access the argument after calling this
- * function. See also: gst_tag_list_ref().
- *
- * Returns: (transfer full): a writable taglist which may or may not be the
- *     same as @taglist
- */
-#define gst_tag_list_make_writable(taglist)   GST_TAG_LIST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (taglist)))
+G_GNUC_WARN_UNUSED_RESULT static inline GstTagList *
+gst_tag_list_make_writable (GstTagList * taglist)
+{
+  return (GstTagList *) (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (taglist)));
+}
+#else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+GST_API
+GstTagList *  gst_tag_list_ref   (GstTagList * taglist);
+
+GST_API
+void          gst_tag_list_unref (GstTagList * taglist);
+
+GST_API
+void          gst_clear_tag_list (GstTagList ** taglist_ptr);
+
+GST_API
+GstTagList*   gst_tag_list_copy  (const GstTagList* taglist) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
+gboolean      gst_tag_list_replace (GstTagList ** old_taglist,
+                                    GstTagList * new_taglist);
+
+GST_API
+gboolean      gst_tag_list_take    (GstTagList ** old_taglist,
+                                    GstTagList * new_taglist);
+
+GST_API
+GstTagList * gst_tag_list_make_writable (GstTagList * taglist) G_GNUC_WARN_UNUSED_RESULT;
+GST_API
+gboolean     gst_tag_list_is_writable   (const GstTagList * taglist);
+#endif
 
 /* GStreamer core tags */
 /**
@@ -1163,6 +1103,18 @@ gst_tag_list_take (GstTagList **old_taglist, GstTagList *new_taglist)
  */
 #define GST_TAG_PRIVATE_DATA                         "private-data"
 
+/**
+ * GST_TAG_CONTAINER_SPECIFIC_TRACK_ID:
+ *
+ * Unique identifier for the audio, video or text track this tag is associated
+ * with. The mappings for several container formats are defined in the [Sourcing
+ * In-band Media Resource Tracks from Media Containers into HTML
+ * specification](https://dev.w3.org/html5/html-sourcing-inband-tracks/).
+ *
+ * Since: 1.24
+ */
+#define GST_TAG_CONTAINER_SPECIFIC_TRACK_ID "container-specific-track-id"
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstTagList, gst_tag_list_unref)
 
 G_END_DECLS
