@@ -259,6 +259,9 @@ GstUri * gst_uri_make_writable         (GstUri * uri) G_GNUC_WARN_UNUSED_RESULT;
 GST_API
 gchar *  gst_uri_to_string             (const GstUri * uri) G_GNUC_MALLOC;
 
+GST_API
+gchar * gst_uri_to_string_with_keys    (const GstUri * uri, const GList *keys);
+
 GST_API
 gboolean gst_uri_is_normalized         (const GstUri * uri);
 
@@ -316,6 +319,9 @@ gboolean gst_uri_append_path_segment   (GstUri * uri,
 GST_API
 gchar * gst_uri_get_query_string       (const GstUri * uri);
 
+GST_API
+gchar * gst_uri_get_query_string_ordered (const GstUri * uri, const GList *keys);
+
 GST_API
 gboolean gst_uri_set_query_string      (GstUri * uri, const gchar * query);
 
@@ -352,7 +358,7 @@ GST_API
 GHashTable * gst_uri_get_media_fragment_table  (const GstUri * uri);
 
 #ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
-static inline GstUri *
+G_GNUC_WARN_UNUSED_RESULT static inline GstUri *
 gst_uri_copy (const GstUri * uri)
 {
   return GST_URI_CAST (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (uri)));
@@ -377,7 +383,7 @@ gst_clear_uri (GstUri ** uri_ptr)
 }
 #else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 GST_API
-GstUri * gst_uri_copy  (const GstUri * uri);
+GstUri * gst_uri_copy  (const GstUri * uri) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
 GstUri * gst_uri_ref   (GstUri * uri);
