@@ -989,12 +989,18 @@ GstPad*                 gst_element_get_compatible_pad  (GstElement *element, Gs
 GST_API
 GstPadTemplate*         gst_element_get_compatible_pad_template (GstElement *element, GstPadTemplate *compattempl);
 
-GST_API
+GST_DEPRECATED_FOR(gst_state_get_name)
 const gchar*            gst_element_state_get_name      (GstState state);
 
-GST_API
+GST_DEPRECATED_FOR(gst_state_change_return_get_name)
 const gchar *           gst_element_state_change_return_get_name (GstStateChangeReturn state_ret);
 
+GST_API
+const gchar*            gst_state_get_name               (GstState state);
+
+GST_API
+const gchar *           gst_state_change_return_get_name (GstStateChangeReturn state_ret);
+
 GST_API
 const gchar *           gst_state_change_get_name       (GstStateChange transition);
 
@@ -1222,6 +1228,9 @@ GST_API
 gboolean      gst_util_fraction_multiply        (gint a_n, gint a_d, gint b_n, gint b_d,
                                                  gint *res_n, gint *res_d);
 GST_API
+gboolean      gst_util_fraction_multiply_int64  (gint64 a_n, gint64 a_d, gint64 b_n, gint64 b_d,
+                                                 gint64 *res_n, gint64 *res_d);
+GST_API
 gboolean      gst_util_fraction_add             (gint a_n, gint a_d, gint b_n, gint b_d,
                                                  gint *res_n, gint *res_d);
 GST_API
@@ -1244,7 +1253,7 @@ GST_API
 guint         gst_util_ceil_log2                (guint32 v);
 
 GST_API
-guint         gst_util_floor_log2               (guint32 x);
+guint         gst_util_floor_log2               (guint32 v);
 
 GST_API
 gint          gst_util_filename_compare        (const gchar *a, const gchar *b);
