@@ -72,6 +72,9 @@ struct _GstNetClientClockClass {
 GST_NET_API
 GType           gst_net_client_clock_get_type	(void);
 
+GST_NET_API
+void            gst_net_client_clock_deinit (void);
+
 GST_NET_API
 GstClock*	gst_net_client_clock_new	(const gchar *name, const gchar *remote_address,
                                                  gint remote_port, GstClockTime base_time);
@@ -97,13 +100,9 @@ GST_NET_API
 GstClock*	gst_ntp_clock_new	        (const gchar *name, const gchar *remote_address,
                                                  gint remote_port, GstClockTime base_time);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstNetClientClock, gst_object_unref)
-#endif
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstNtpClock, gst_object_unref)
-#endif
 
 G_END_DECLS
 
