@@ -166,6 +166,24 @@ gst_test_aggregator_aggregate (GstAggregator * aggregator, gboolean timeout)
 #define gst_test_aggregator_parent_class parent_class
 G_DEFINE_TYPE (GstTestAggregator, gst_test_aggregator, GST_TYPE_AGGREGATOR);
 
+static gboolean gst_aggregator_test_slow_down_sink_query = FALSE;
+
+static gboolean
+gst_aggregator_test_slow_sink_query (GstAggregator * self,
+    GstAggregatorPad * aggpad, GstQuery * query)
+{
+  GST_DEBUG ("Handling query %" GST_PTR_FORMAT, query);
+  if (GST_QUERY_IS_SERIALIZED (query)) {
+    GstStructure *s = gst_query_writable_structure (query);
+
+    if (gst_aggregator_test_slow_down_sink_query)
+      g_usleep (G_TIME_SPAN_MILLISECOND * 10);
+    gst_structure_set (s, "some-int", G_TYPE_INT, 123, NULL);
+    GST_DEBUG ("Written to the query %" GST_PTR_FORMAT, query);
+  }
+  return GST_AGGREGATOR_CLASS (parent_class)->sink_query (self, aggpad, query);
+}
+
 static void
 gst_test_aggregator_class_init (GstTestAggregatorClass * klass)
 {
@@ -193,6 +211,7 @@ gst_test_aggregator_class_init (GstTestAggregatorClass * klass)
       GST_DEBUG_FUNCPTR (gst_test_aggregator_aggregate);
 
   base_aggregator_class->get_next_time = gst_aggregator_simple_get_next_time;
+  base_aggregator_class->sink_query = gst_aggregator_test_slow_sink_query;
 }
 
 static void
@@ -646,6 +665,60 @@ GST_START_TEST (test_aggregate_handle_queries)
 
 GST_END_TEST;
 
+GST_START_TEST (test_aggregate_queries_robustness)
+{
+  GThread *thread1;
+  ChainData data1 = { 0, };
+  TestData test = { 0, };
+  GstCaps *caps;
+  gint64 start_time;
+
+  gst_aggregator_test_slow_down_sink_query = TRUE;
+
+  _test_data_init (&test, FALSE);
+
+  caps = gst_caps_new_empty_simple ("foo/x-bar");
+  _chain_data_init (&data1, test.aggregator,
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE),
+      gst_query_new_allocation (caps, FALSE), NULL);
+  gst_caps_unref (caps);
+
+  thread1 = g_thread_try_new ("gst-check", push_data, &data1, NULL);
+  g_usleep (G_TIME_SPAN_MILLISECOND * 5);
+  for (start_time = g_get_monotonic_time ();
+      start_time + G_TIME_SPAN_SECOND > g_get_monotonic_time ();
+      g_usleep (G_TIME_SPAN_MILLISECOND)) {
+    fail_unless (gst_element_send_event (test.aggregator,
+            gst_event_new_flush_start ()));
+    fail_unless (gst_element_send_event (test.aggregator,
+            gst_event_new_flush_stop (TRUE)));
+  }
+
+  g_thread_join (thread1);
+
+  _chain_data_clear (&data1);
+  _test_data_clear (&test);
+
+  gst_aggregator_test_slow_down_sink_query = FALSE;
+}
+
+GST_END_TEST;
+
 #define NUM_BUFFERS 3
 static void
 handoff (GstElement * fakesink, GstBuffer * buf, GstPad * pad, guint * count)
@@ -1147,7 +1220,7 @@ GST_START_TEST (test_add_remove)
               gst_pad_add_probe (pad, GST_PAD_PROBE_TYPE_BLOCK_DOWNSTREAM,
                   (GstPadProbeCallback) pad_probe_cb, &data, NULL);
               GST_INFO ("Waiting for %" GST_PTR_FORMAT " %s", pad,
-                  gst_element_state_get_name (GST_STATE (data.src)));
+                  gst_state_get_name (GST_STATE (data.src)));
               g_cond_wait (&cond, &lock);
               g_mutex_unlock (&lock);
               gst_object_unref (pad);
@@ -1242,7 +1315,7 @@ GST_START_TEST (test_change_state_intensive)
       wanted_state = wanted_states[state_i++];
       fail_unless (gst_element_set_state (pipeline, wanted_state),
           GST_STATE_CHANGE_SUCCESS);
-      GST_INFO ("Wanted state: %s", gst_element_state_get_name (wanted_state));
+      GST_INFO ("Wanted state: %s", gst_state_get_name (wanted_state));
     }
 
     message = gst_bus_poll (bus, GST_MESSAGE_ANY, GST_SECOND / 10);
@@ -1267,11 +1340,9 @@ GST_START_TEST (test_change_state_intensive)
               break;
             }
 
-            GST_DEBUG ("State %s reached",
-                gst_element_state_get_name (wanted_state));
+            GST_DEBUG ("State %s reached", gst_state_get_name (wanted_state));
             wanted_state = wanted_states[state_i++];
-            GST_DEBUG ("Wanted state: %s",
-                gst_element_state_get_name (wanted_state));
+            GST_DEBUG ("Wanted state: %s", gst_state_get_name (wanted_state));
             state_return = gst_element_set_state (pipeline, wanted_state);
             fail_unless (state_return == GST_STATE_CHANGE_SUCCESS ||
                 state_return == GST_STATE_CHANGE_ASYNC);
@@ -1398,6 +1469,7 @@ gst_aggregator_suite (void)
   tcase_add_test (general, test_aggregate_gap);
   tcase_add_test (general, test_aggregate_handle_events);
   tcase_add_test (general, test_aggregate_handle_queries);
+  tcase_add_test (general, test_aggregate_queries_robustness);
   tcase_add_test (general, test_flushing_seek);
   tcase_add_test (general, test_infinite_seek);
   tcase_add_test (general, test_infinite_seek_50_src);
