@@ -153,7 +153,7 @@ gst_test_obj_base_init (GstTestObjClass * klass)
 static GType
 gst_test_obj_get_type (void)
 {
-  static volatile gsize TEST_OBJ_type = 0;
+  static gsize TEST_OBJ_type = 0;
 
   if (g_once_init_enter (&TEST_OBJ_type)) {
     GType type;
